import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-DYeVROnq.js";import{B as y}from"./BaseLayout-DP0bVFSH.js";import{a as l,P as _,a1 as b,aN as u,aG as v,aH as g,e as f,b as h,h as a,K as s,D as w,ad as S,p as k,w as n,ac as B,j as i,u as I}from"./jwt-decode.esm-Cqi12V-N.js";import{u as $}from"./editor-B8GXdOvY.js";import{A as D}from"./index-BZof8Hij.js";import"./Logo-BTCvt8sQ.js";import"./router-B0oUoysq.js";import"./workspaceStore-BgkodCey.js";import"./userStore-CtmAFW7E.js";import"./url-BVQP5Ns3.js";import"./colorHelpers-B377H3T6.js";import"./useCodebaseEvents-Cv5fcZaL.js";import"./contracts.generated-BESrwOwd.js";import"./ts.worker-B6T9w9Ua.js";import"./constants-CnytNyhp.js";import"./linters-BV98an5e.js";import"./asyncComputed-ClqYWeom.js";import"./index-B1jPs2Ta.js";import"./index-Bf4MB6er.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="e4408801-4c7e-4a24-9037-b6b33b295604",e._sentryDebugIdIdentifier="sentry-dbid-e4408801-4c7e-4a24-9037-b6b33b295604")}catch{}})();const L=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),P={class:"v-spinner"};function x(e,r,o,d,c,p){return v((f(),h("div",P,[a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u(L,[["render",x],["__scopeId","data-v-06538001"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const r=B(),o=S(),d=$();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){o.push({name:"error"});return}await d.createLogin(t).then(c),o.push({name:"editor"})}),(t,z)=>(f(),k(y,null,{navbar:n(()=>[i(I(D),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[a("div",R,[i(K)])]),_:1}))}}),ee=u(j,[["__scopeId","data-v-d2a19803"]]);export{ee as default};
//# sourceMappingURL=ProjectLogin-4cjXnonx.js.map
