import{_ as d}from"./Login.vue_vue_type_script_setup_true_lang-Cxa0PHTn.js";import{a as p,b as u,j as i,u as n,ad as l,ac as m,e as f,aN as _}from"./jwt-decode.esm-Cqi12V-N.js";import{u as b}from"./workspaceStore-BgkodCey.js";import"./CircularLoading-D6Xi8qeu.js";import"./Logo-BTCvt8sQ.js";import"./string-USUkOvGu.js";import"./index-B0s_uG-_.js";import"./userStore-CtmAFW7E.js";import"./url-BVQP5Ns3.js";import"./colorHelpers-B377H3T6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="15d36da3-3eda-4f73-a27b-bc4199b7024c",e._sentryDebugIdIdentifier="sentry-dbid-15d36da3-3eda-4f73-a27b-bc4199b7024c")}catch{}})();const g={class:"runner"},y=p({__name:"Login",setup(e){const o=l(),a=m(),r=b(),c=async()=>{const{redirect:t,...s}=a.query;if(t){await o.push({path:t,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(f(),u("div",g,[i(d,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),E=_(y,[["__scopeId","data-v-12c690e1"]]);export{E as default};
//# sourceMappingURL=Login-CtFkRwnc.js.map
