import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-mKxaqFsj.js";import{a as i,ac as s,p as a,e as m,u as c}from"./jwt-decode.esm-Cqi12V-N.js";import"./router-Dc2CEtZs.js";import"./ts.worker-B6T9w9Ua.js";import"./fetch-DX3wUr-c.js";import"./record-drY-gKry.js";import"./SaveButton-DvQA4if5.js";import"./ExclamationCircleOutlined-DiIJzKTA.js";import"./CrudView-Cy08eecj.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DcHuXW8J.js";import"./constants-CnytNyhp.js";import"./url-BVQP5Ns3.js";import"./PhDotsThreeVertical.vue-BnpXkzyI.js";import"./index-B1jPs2Ta.js";import"./asyncComputed-ClqYWeom.js";import"./omniChatStore-EZvnUcgY.js";import"./uuid-ClHb9zsJ.js";import"./PhCopySimple.vue-DMDMlJNj.js";import"./PhPencil.vue-BoVVsHS_.js";import"./useCodebaseEvents-Cv5fcZaL.js";import"./contracts.generated-BESrwOwd.js";import"./index-B0s_uG-_.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="399a24f0-44c0-41ba-850c-8bfe7e7f3591",o._sentryDebugIdIdentifier="sentry-dbid-399a24f0-44c0-41ba-850c-8bfe7e7f3591")}catch{}})();const A=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(f,d)=>(m(),a(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-CP_s_3gs.js.map
