const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-CwvgV7sj.js","assets/workspaceStore-BgkodCey.js","assets/jwt-decode.esm-Cqi12V-N.js","assets/jwt-decode-UwARlUKu.css","assets/userStore-CtmAFW7E.js","assets/url-BVQP5Ns3.js","assets/colorHelpers-B377H3T6.js","assets/OidcLogoutCallback-Bn6xmQvK.js","assets/Login-CtFkRwnc.js","assets/Login.vue_vue_type_script_setup_true_lang-Cxa0PHTn.js","assets/CircularLoading-D6Xi8qeu.js","assets/CircularLoading-C7OKHy4X.css","assets/Logo-BTCvt8sQ.js","assets/Logo-D2kepPyK.css","assets/string-USUkOvGu.js","assets/index-B0s_uG-_.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-CG7rPRos.js","assets/PlayerNavbar-DvSFPe5s.js","assets/metadata-DQBLBF-_.js","assets/PhWebhooksLogo.vue-D1Sad6I4.js","assets/LoadingOutlined-CHQyVeWB.js","assets/PhSignOut.vue-BlODgy33.js","assets/index-Bf4MB6er.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-DHUQOMfW.js","assets/Watermark-BANKc_28.js","assets/constants-CnytNyhp.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-D7Ph3Tz-.js","assets/index-Ddp9_h4l.js","assets/Home-B6UGln4L.css","assets/Error-jKKb1xNT.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-DYeVROnq.js","assets/Error-CIbhyrKS.css","assets/Form-Ck02_xvO.js","assets/FormRunner-CxaxRfi0.js","assets/Steps-D0LCkq8H.js","assets/index-DCXMFt6L.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-61-wByB6.css","assets/redirect-B1JuIdLG.js","assets/asyncComputed-ClqYWeom.js","assets/uuid-ClHb9zsJ.js","assets/Form-BkLIfVj9.css"])))=>i.map(i=>d[i]);
import{af as s,ag as c,ah as t,ai as m}from"./jwt-decode.esm-Cqi12V-N.js";import{a as u}from"./workspaceStore-BgkodCey.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ea613126-b168-4de5-91a8-551540e46ace",e._sentryDebugIdIdentifier="sentry-dbid-ea613126-b168-4de5-91a8-551540e46ace")}catch{}})();const b=async()=>{try{const e=await fetch("/_editor/api/workspace/version");return e.ok&&(await e.json()).version||"d1ae08c0e5961d7d39befdf21d5b1d7e43f0615d"}catch(e){return console.error("Failed to fetch Abstra version:",e),"d1ae08c0e5961d7d39befdf21d5b1d7e43f0615d"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-CwvgV7sj.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-Bn6xmQvK.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-CtFkRwnc.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-CG7rPRos.js"),__vite__mapDeps([18,19,4,2,3,1,5,6,20,21,22,23,24,25,26])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-DHUQOMfW.js"),__vite__mapDeps([27,20,2,3,21,28,1,4,5,6,29,30,31,32,22,33])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-jKKb1xNT.js"),__vite__mapDeps([34,35,12,2,3,13,29,1,4,5,6,32,36])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-Ck02_xvO.js"),__vite__mapDeps([37,4,2,3,38,9,1,5,6,10,11,12,13,14,15,16,39,40,41,28,29,30,42,43,44,45,46])),meta:{hideLogin:!0}}]}],o=s({history:c("/"),routes:p,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),l=e=>async(a,r)=>{if(m(a,r),a.meta.allowUnauthenticated)return;const n=await u(a.path),{redirect:d,...i}=a.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await e.push({name:"playerLogin",query:{...i,redirect:d||a.path},params:a.params});break;case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,b as g,o as r};
//# sourceMappingURL=router-B0oUoysq.js.map
